@@ -79,7 +79,7 @@ static MagnifierOptions global_options = { ":0.0",
 					   500,
 					   50,
 					   0,
-					   1.0F,
+					   0.0F,
 					   0xFF000000,
 					   0,
 					   0,
@@ -416,9 +416,12 @@ main (int argc, char** argv)
 	  bonobo_pbclient_set_long (properties, "cursor-size",
 				    global_options.cursor_size, NULL);
 
-  else if (global_options.cursor_scale_factor != 1.0F)
+  else if (global_options.cursor_scale_factor != 0.0F)
 	  bonobo_pbclient_set_float (properties, "cursor-scale-factor",
 				     global_options.cursor_scale_factor, NULL);
+  else 
+	  bonobo_pbclient_set_float (properties, "cursor-scale-factor",
+				     global_options.zoom_factor, NULL);
 
   if (global_options.cursor_color)
 	  bonobo_pbclient_set_ulong (properties, "cursor-color",
@@ -471,7 +474,7 @@ main (int argc, char** argv)
   {
 	  int scroll_policy;
 	  
-	  fprintf (stderr, "creating an initial zoom region.\n");
+	  fprintf (stderr, "Creating an initial zoom region.\n");
 	  init_rect_bounds (roi, 0, 0, 100, 100);
 	  init_rect_bounds (viewport, 0, 0, screen_width, screen_height);
 	  zoom_region =
@@ -497,7 +500,6 @@ main (int argc, char** argv)
 				       global_options.timing_output, &ev);
 	  bonobo_pbclient_set_long (properties, "timing-pan-rate",
 				       global_options.timing_pan_rate, &ev);
-	  g_message ("setting zoom properties border-size to %d\n", global_options.border_width);
 	  bonobo_pbclient_set_long    (properties, "border-size",
 				       global_options.border_width, &ev);
 	  bonobo_pbclient_set_long    (properties, "border-color",
