@@ -283,9 +283,12 @@ magnifier_set_cursor_from_pixbuf (Magnifier *magnifier, GdkPixbuf *cursor_pixbuf
 		height = gdk_pixbuf_get_height (cursor_pixbuf);
 		pixmap = gdk_pixmap_new (drawable, width, height, -1);
 		gc = gdk_gc_new (pixmap);
-		gdk_draw_pixbuf (pixmap, gc, cursor_pixbuf, 0, 0, 0, 0, 
-				 width, height,
-				 GDK_RGB_DITHER_NONE, 0, 0);
+		if (GDK_IS_DRAWABLE (pixmap))
+		    gdk_draw_pixbuf (pixmap, gc, cursor_pixbuf, 0, 0, 0, 0, 
+				     width, height,
+				     GDK_RGB_DITHER_NONE, 0, 0);
+		else
+		    DBG (g_warning ("empty cursor pixmap created."));
 		mask = gdk_pixmap_new (drawable, width, height, 1);
 		gdk_pixbuf_render_threshold_alpha (cursor_pixbuf, mask, 0, 0, 0, 0, 
 						   width, height,
@@ -834,17 +837,24 @@ magnifier_transform_cursor (Magnifier *magnifier)
 			magnifier->priv->w->window,
 			size_x, size_y,
 			-1);
-		if (!magnifier->priv->cursor) g_warning ("magnifier cursur pixmap is non-null");
+		if (!GDK_IS_DRAWABLE (magnifier->priv->cursor)) 
+		{
+		    DBG (g_warning ("NULL magnifier cursor pixmap."));
+		    return;
+		}
 		magnifier->priv->cursor_mask = gdk_pixmap_new (
 			magnifier->priv->w->window,
 			size_x, size_y,
 			1);
-
-		gdk_draw_pixbuf (magnifier->priv->cursor,
-				 cgc,
-				 scaled_cursor_pixbuf,
-				 0, 0, 0, 0, size_x, size_y,
-				 GDK_RGB_DITHER_NONE, 0, 0 );
+		if (GDK_IS_DRAWABLE (magnifier->priv->cursor)) {
+		    gdk_draw_pixbuf (magnifier->priv->cursor,
+				     cgc,
+				     scaled_cursor_pixbuf,
+				     0, 0, 0, 0, size_x, size_y,
+				     GDK_RGB_DITHER_NONE, 0, 0 );
+		}
+		else
+		    DBG (g_warning ("cursor pixmap is non-drawable."));
 		scaled_mask_pixbuf = gdk_pixbuf_add_alpha (
 			scaled_mask_pixbuf, True, 0, 0, 0);
 		gdk_pixbuf_render_threshold_alpha (scaled_mask_pixbuf,
@@ -1130,7 +1140,7 @@ magnifier_set_property (BonoboPropertyBag *bag,
 		    magnifier_get_display_rect_bounds (magnifier, &magnifier->source_bounds, FALSE);
 		    magnifier_check_set_struts (magnifier);
 		}
-		DBG (fprintf (stderr, "Set source display: \t%d\n", full_display_string));
+		DBG (fprintf (stderr, "Set source display: \t%s\n", full_display_string));
 		break;
 	case MAGNIFIER_TARGET_DISPLAY_PROP:
 		full_display_string = BONOBO_ARG_GET_STRING (arg);
@@ -1144,17 +1154,35 @@ magnifier_set_property (BonoboPropertyBag *bag,
 			gdk_display_open (full_display_string);
 		    magnifier->target_display_name = g_strdup (full_display_string);
 		    if (GTK_IS_WINDOW (magnifier->priv->w)) 
+		    {
+#ifdef REPARENT_GTK_WINDOW_WORKS
 			gtk_window_set_screen (GTK_WINDOW (magnifier->priv->w), 
 					       gdk_display_get_screen (
 						   magnifier->target_display,
 						   magnifier->target_screen_num));
+#else
+			/* disconnect from the old window's destroy signal */
+			g_object_disconnect (magnifier->priv->w,
+				  "any_signal::realize", magnifier_realize, NULL,
+				  "any_signal::size_allocate", magnifier_size_allocate, NULL,
+				  "any_signal::destroy", magnifier_exit, NULL,
+			          NULL);
+			/* destroy the old windows */
+			gtk_widget_destroy (magnifier->priv->w);
+			/* and re-initialize... */
+			magnifier_init_window (magnifier, gdk_display_get_screen (
+						   magnifier->target_display,
+						   magnifier->target_screen_num));
+#endif
+		    }
 		    magnifier_get_display_rect_bounds (magnifier, &magnifier->target_bounds, TRUE);
 		    magnifier_get_display_rect_bounds (magnifier, &magnifier->source_bounds, FALSE);
 		    magnifier_reparent_zoom_regions (magnifier);
 		    magnifier_init_cursor_set (magnifier, magnifier->cursor_set); /* needed to reset pixmaps */
 		    magnifier_check_set_struts (magnifier);
 		}
-		DBG (fprintf (stderr, "Set target display: \t%d\n", full_display_string));
+		DBG (fprintf (stderr, "Set target display: \t%s (screen %d)\n", 
+			      full_display_string, magnifier->target_screen_num));
 		break;
 	case MAGNIFIER_SOURCE_SIZE_PROP:
 	        magnifier->source_bounds = BONOBO_ARG_GET_GENERAL (arg,
@@ -1646,7 +1674,7 @@ magnifier_properties_init (Magnifier *magnifier)
 }
 
 static void
-magnifier_init_window (Magnifier *magnifier)
+magnifier_init_window (Magnifier *magnifier, GdkScreen *screen)
 {
 	GtkWindowType mag_win_type = GTK_WINDOW_TOPLEVEL;
 	if (_is_override_redirect) mag_win_type = GTK_WINDOW_POPUP;
@@ -1665,6 +1693,7 @@ magnifier_init_window (Magnifier *magnifier)
 				  "signal::size_allocate", magnifier_size_allocate, NULL,
 				  "signal::destroy", magnifier_exit, NULL,
 				  NULL);
+	gtk_window_set_screen (magnifier->priv->w, screen);
 	magnifier->priv->canvas = gtk_fixed_new ();
 	gtk_container_add (GTK_CONTAINER (magnifier->priv->w),
 			   magnifier->priv->canvas);
@@ -1694,7 +1723,9 @@ magnifier_init (Magnifier *magnifier)
 	magnifier->priv->w = NULL;
 	magnifier->priv->use_source_cursor = TRUE;
 	magnifier->priv->cursorlist = NULL;
-	magnifier_init_window (magnifier);
+	magnifier_init_window (magnifier, 
+			       gdk_display_get_screen (magnifier->target_display, 
+						       magnifier->target_screen_num));
 	magnifier_init_cursor_set (magnifier, "default");
 }
 
